@@ -1877,7 +1877,7 @@ std::string serializeIncidence(const typename T::IncidenceType &incidence, const
         }
 
         typename KolabType::properties_type::created_type created;
-        if (incidence.created().isValid()) {
+        if (incidence.created().isValid() && !incidence.created().isDateOnly()) {
             created.date_time(fromDateTime(incidence.created()));
         } else {
             created.date_time(fromDateTime(timestamp()));
